@@ -1,8 +1,8 @@
 
-__version__ = "0.12"
+__version__ = "0.12.1"
 __version_vcs_info__ = {
     'branch': 'master',
-    'revid': '81cf516',
-    'revno': 2093}
+    'revid': '2320de6',
+    'revno': 2127}
 __version_user_email__ = "saxtouri@admin.grnet.gr"
 __version_user_name__ = "Stavros Sachtouris"
